==> qore-1.19.2.tar.bz2: qore-1.19.2/docs/library/html/common_8h.js <==
var common_8h =
[
    [ "cstr_vector_t", "classcstr__vector__t.html", null ],
    [ "free_ptr", "structfree__ptr.html", null ],
    [ "ltchar", "classltchar.html", null ],
    [ "ltcstrcase", "classltcstrcase.html", null ],
    [ "ltstr", "classltstr.html", null ],
    [ "ltstrcase", "classltstrcase.html", null ],
    [ "QoreDeserializationContext", "class_qore_deserialization_context.html", "class_qore_deserialization_context" ],
    [ "QoreSerializationContext", "class_qore_serialization_context.html", "class_qore_serialization_context" ],
    [ "simple_delete", "structsimple__delete.html", null ],
    [ "simple_deref", "structsimple__deref.html", null ],
    [ "Q_AF_INET", "common_8h.html#a068cce92117a6572291ed8dff249a119", null ],
    [ "Q_AF_INET6", "common_8h.html#a717fbc6e6074778b646336f4306bcfb1", null ],
    [ "Q_AF_UNSPEC", "common_8h.html#a4809f2ad9827026d46c189622debb487", null ],
    [ "Q_SOCK_STREAM", "common_8h.html#ad2d61ed9fb3309f5de1f042e2629560e", null ],
    [ "arg_vec_t", "common_8h.html#afc12ca95c1bc2b2fcd66387aaf9ce634", null ],
    [ "int64", "common_8h.html#aecfc3c54bd29ad5964e1c1c3ccbf89df", null ],
    [ "int_set_t", "common_8h.html#a7e904455ea8c276e85f717dde452ebc5", null ],
    [ "name_vec_t", "common_8h.html#acab02375bd22f5c02f9d36c38129b7a8", null ],
    [ "q_constructor_n_t", "common_8h.html#afc086132197888599e9f7bd478d5faa4", null ],
    [ "q_copy_t", "common_8h.html#a53687c29bb546736e82ddb354c2f1fe7", null ],
    [ "q_deserializer_t", "common_8h.html#adf4e475c65f90f3d5dac872e1f4417b0", null ],
    [ "q_destructor_t", "common_8h.html#aafe4fbadbcbdaf28c92204d810704f5f", null ],
    [ "q_external_constructor_t", "common_8h.html#a7f429a7ff7764c12098f7d2f00dadb23", null ],
    [ "q_external_copy_t", "common_8h.html#ab145950a57e839b680b57ed3848202fd", null ],
    [ "q_external_destructor_t", "common_8h.html#a275ebca16561ad2bbdf74ef112037375", null ],
    [ "q_external_func_t", "common_8h.html#afaea0c9dfcfe045fa30449b6977d6bff", null ],
    [ "q_external_method_t", "common_8h.html#a0f124044f5db95653892e5fa5e1ddf28", null ],
    [ "q_external_static_method_t", "common_8h.html#a4899be921f94943289b0e0bc14ffdfe8", null ],
    [ "q_func_n_t", "common_8h.html#a5291a40a517e109bfe10c517887e3f7f", null ],
    [ "q_method_n_t", "common_8h.html#a7438b1b0591fd0acc5756b9f52e2356d", null ],
    [ "q_rt_flags_t", "common_8h.html#a32e65b4ec52c7cc909cf56f48e220a60", null ],
    [ "q_serializer_t", "common_8h.html#a243b10fb2a734c0e9703e4e59dfab2d1", null ],
    [ "q_system_constructor_t", "common_8h.html#a60721ea33dfdc7ed5208b11bb4915b00", null ],
    [ "q_trid_t", "common_8h.html#aa01efb0fa9033a8f864a792d62bec655", null ],
    [ "qore_classid_t", "common_8h.html#ac131e871d6ca3f3ed17037506ae0e590", null ],
    [ "qore_offset_t", "common_8h.html#ae36a61dcce5acc5803df1f7a3286de6f", null ],
    [ "qore_size_t", "common_8h.html#ae8ecbfc48e137b4f94ac6d5cccbe0f36", null ],
    [ "qore_type_t", "common_8h.html#a30330613e5f8dd81afda4ec9b361a5d8", null ],
    [ "type_vec_t", "common_8h.html#a87b04b9fd63a1b7fd159ef3e44a70e9d", null ],
    [ "qore_license_t", "common_8h.html#aaddd4ef74b4336e3c820e81ace356714", [
      [ "QL_GPL", "common_8h.html#aaddd4ef74b4336e3c820e81ace356714a200fd8cdf303bf70950eacabeddbf3c1", null ],
      [ "QL_LGPL", "common_8h.html#aaddd4ef74b4336e3c820e81ace356714ab9ff768c31b7fe09693dcd30d02b7283", null ],
      [ "QL_MIT", "common_8h.html#aaddd4ef74b4336e3c820e81ace356714afac20e6662c76e48ce37d167c04e5bf3", null ]
    ] ],
    [ "q_atoll", "common_8h.html#a3e052d2b2f2ac48bfe1c4cc3faaeaeb4", null ],
    [ "type_get_name", "common_8h.html#a9af0c1c57d23efb9f81b7f8946f66104", null ]
];

==> qore-2.2.0.tar.bz2: qore-2.2.0/docs/library/html/common_8h.js <==
var common_8h =
[
    [ "cstr_vector_t", "classcstr__vector__t.html", null ],
    [ "free_ptr< T >", "structfree__ptr.html", null ],
    [ "ltchar", "classltchar.html", null ],
    [ "ltcstrcase", "classltcstrcase.html", null ],
    [ "ltstr", "classltstr.html", null ],
    [ "ltstrcase", "classltstrcase.html", null ],
    [ "QoreDeserializationContext", "class_qore_deserialization_context.html", "class_qore_deserialization_context" ],
    [ "QoreSerializationContext", "class_qore_serialization_context.html", "class_qore_serialization_context" ],
    [ "simple_delete< T >", "structsimple__delete.html", null ],
    [ "simple_deref< T >", "structsimple__deref.html", null ],
    [ "Q_AF_INET", "common_8h.html#a068cce92117a6572291ed8dff249a119", null ],
    [ "Q_AF_INET6", "common_8h.html#a717fbc6e6074778b646336f4306bcfb1", null ],
    [ "Q_AF_UNSPEC", "common_8h.html#a4809f2ad9827026d46c189622debb487", null ],
    [ "Q_SOCK_STREAM", "common_8h.html#ad2d61ed9fb3309f5de1f042e2629560e", null ],
    [ "arg_vec_t", "common_8h.html#afc12ca95c1bc2b2fcd66387aaf9ce634", null ],
    [ "int64", "common_8h.html#aecfc3c54bd29ad5964e1c1c3ccbf89df", null ],
    [ "int_set_t", "common_8h.html#a7e904455ea8c276e85f717dde452ebc5", null ],
    [ "name_vec_t", "common_8h.html#acab02375bd22f5c02f9d36c38129b7a8", null ],
    [ "q_constructor_n_t", "common_8h.html#afc086132197888599e9f7bd478d5faa4", null ],
    [ "q_copy_t", "common_8h.html#a53687c29bb546736e82ddb354c2f1fe7", null ],
    [ "q_deserializer_t", "common_8h.html#adf4e475c65f90f3d5dac872e1f4417b0", null ],
    [ "q_destructor_t", "common_8h.html#aafe4fbadbcbdaf28c92204d810704f5f", null ],
    [ "q_external_constructor_t", "common_8h.html#a7f429a7ff7764c12098f7d2f00dadb23", null ],
    [ "q_external_copy_t", "common_8h.html#ab145950a57e839b680b57ed3848202fd", null ],
    [ "q_external_destructor_t", "common_8h.html#a275ebca16561ad2bbdf74ef112037375", null ],
    [ "q_external_func_t", "common_8h.html#afaea0c9dfcfe045fa30449b6977d6bff", null ],
    [ "q_external_method_t", "common_8h.html#a0f124044f5db95653892e5fa5e1ddf28", null ],
    [ "q_external_static_method_t", "common_8h.html#a4899be921f94943289b0e0bc14ffdfe8", null ],
    [ "q_func_n_t", "common_8h.html#a5291a40a517e109bfe10c517887e3f7f", null ],
    [ "q_method_n_t", "common_8h.html#a7438b1b0591fd0acc5756b9f52e2356d", null ],
    [ "q_rt_flags_t", "common_8h.html#a32e65b4ec52c7cc909cf56f48e220a60", null ],
    [ "q_serializer_t", "common_8h.html#a8ebfb0c8ae04e440a396127537e86352", null ],
    [ "q_system_constructor_t", "common_8h.html#a60721ea33dfdc7ed5208b11bb4915b00", null ],
    [ "q_trid_t", "common_8h.html#aa01efb0fa9033a8f864a792d62bec655", null ],
    [ "qore_classid_t", "common_8h.html#ac131e871d6ca3f3ed17037506ae0e590", null ],
    [ "qore_offset_t", "common_8h.html#ae36a61dcce5acc5803df1f7a3286de6f", null ],
    [ "qore_size_t", "common_8h.html#ae8ecbfc48e137b4f94ac6d5cccbe0f36", null ],
    [ "qore_type_t", "common_8h.html#a30330613e5f8dd81afda4ec9b361a5d8", null ],
    [ "type_vec_t", "common_8h.html#a87b04b9fd63a1b7fd159ef3e44a70e9d", null ],
    [ "qore_license_t", "common_8h.html#aaddd4ef74b4336e3c820e81ace356714", [
      [ "QL_GPL", "common_8h.html#aaddd4ef74b4336e3c820e81ace356714a200fd8cdf303bf70950eacabeddbf3c1", null ],
      [ "QL_LGPL", "common_8h.html#aaddd4ef74b4336e3c820e81ace356714ab9ff768c31b7fe09693dcd30d02b7283", null ],
      [ "QL_MIT", "common_8h.html#aaddd4ef74b4336e3c820e81ace356714afac20e6662c76e48ce37d167c04e5bf3", null ]
    ] ],
    [ "q_atoll", "common_8h.html#a3e052d2b2f2ac48bfe1c4cc3faaeaeb4", null ],
    [ "type_get_name", "common_8h.html#a308049a9a3ddb2432873f910a289d533", null ],
    [ "QDF_MERGE_STATIC_CLASS_VARS", "common_8h.html#affb662a2c36100dfca77dca111c92bc5", null ],
    [ "QDF_STATIC_CLASS_VARS", "common_8h.html#a590136cf57aefdfffaed5528d8f9f704", null ],
    [ "QSF_INCLUDE_STATIC_CLASS_VARS", "common_8h.html#a20726430595baef7008b18e4a92ca277", null ]
];
